@@ -1,21 +1,33 @@
 import sys
 import argparse
+import configparser
 import networkx as nx
 import pickle as cp
 import os
 
+
 # Some filenames
-FILE_ALTERNATE_ID_TO_ID_MAPPING = "data/alt_to_id.graph"
-FILE_CAFA_ID_TO_UNIPROT_ID_MAP = "data/CAFAIDTOUniprotIDMap.txt"
-FILE_MFO_ONTOLOGY_GRAPH = "data/mf.graph"
-FILE_BPO_ONTOLOGY_GRAPH = "data/bp.graph"
-FILE_CCO_ONTOLOGY_GRAPH = "data/cc.graph"
-FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = "data/mf_ancestors.map"
-FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = "data/bp_ancestors.map"
-FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = "data/cc_ancestors.map"
-ROOT_BPO = 'GO:0008150'
-ROOT_CCO = 'GO:0005575'
-ROOT_MFO = 'GO:0003674'
+# FILE_ALTERNATE_ID_TO_ID_MAPPING = "data/alt_to_id.graph"
+# FILE_CAFA_ID_TO_UNIPROT_ID_MAP = "data/CAFAIDTOUniprotIDMap.txt"
+# FILE_MFO_ONTOLOGY_GRAPH = "data/mf.graph"
+# FILE_BPO_ONTOLOGY_GRAPH = "data/bp.graph"
+# FILE_CCO_ONTOLOGY_GRAPH = "data/cc.graph"
+# FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = "data/mf_ancestors.map"
+# FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = "data/bp_ancestors.map"
+# FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = "data/cc_ancestors.map"
+
+# Iddo: fixed paths to incorporate ONTO_DIR (passed as an argument from argparse)
+# FILE_ALTERNATE_ID_TO_ID_MAPPING = "alt_to_id.graph"
+# FILE_CAFA_ID_TO_UNIPROT_ID_MAP = "CAFAIDTOUniprotIDMap.txt"
+# FILE_MFO_ONTOLOGY_GRAPH = "mf.graph"
+# FILE_BPO_ONTOLOGY_GRAPH = "bp.graph"
+# FILE_CCO_ONTOLOGY_GRAPH = "cc.graph"
+# FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = "mf_ancestors.map"
+# FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = "bp_ancestors.map"
+# FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = "cc_ancestors.map"
+# ROOT_BPO = 'GO:0008150'
+# ROOT_CCO = 'GO:0005575'
+# ROOT_MFO = 'GO:0003674'
 
 
 def findAllAncestors(g, node):
@@ -28,7 +40,7 @@ def findAllAncestors(g, node):
     return list(set(ancestors))
 
 
-def parseGOTerms(inputfile, keepobsolete):
+def parseGOTerms(inputfile):
     fhr = open(inputfile, "r")
     mf_g = nx.DiGraph()
     cc_g = nx.DiGraph()
@@ -66,9 +78,10 @@ def parseGOTerms(inputfile, keepobsolete):
         for line in split_term:
             if "id:" in line and "GO:" in line and "alt_id" not in line:
                 GO_term = "GO:" + line.split("GO:")[-1].strip()
+            alt_id = ''
             if "GO:" in line and "alt_id" in line:
                 alt_id = "GO:" + line.split("GO:")[-1].strip()
-                alt_id_to_id_mapping[alt_id] = GO_term
+                alt_id_to_id_mapping[alt_id] = [GO_term]
             if "namespace: biological_process" in line:
                 namespace = "bp"
             elif "namespace: cellular_component" in line:
@@ -76,6 +89,10 @@ def parseGOTerms(inputfile, keepobsolete):
             elif "namespace: molecular_function" in line:
                 namespace = "mf"
 
+            if alt_id != '':
+                alt_id_to_id_mapping[alt_id].append(namespace)
+
+            # Iddo: this looks dangerous!
             if ("is_a:" in line or "relationship: part_of" in line) and "GO" in line:
                 if "is_a" in line:
                     relation = "is_a"
@@ -84,7 +101,7 @@ def parseGOTerms(inputfile, keepobsolete):
                 try:
                     parent_GO_term = "GO:" + line.split("GO:")[1][:7]
                 except IndexError:
-                    print(line)
+                    print(f"Error in obo file {line}")
                     exit()
 
                 # print(GO_term,line)
@@ -100,14 +117,18 @@ def parseGOTerms(inputfile, keepobsolete):
 
 def parseCommandLineArguments():
     """
+    Iddo: Fix this docstring
     Please do not use this function yet.
     """
     parser = argparse.ArgumentParser(prog="gothresher_prep.py")
 
-    parser.add_argument("--input", "-i", help="The input file to be parsed", required=True)
+    parser.add_argument("--config", "-c", help="INI file. gothresher.ini", default=os.getcwd()+"/gothresher.ini")
+    parser.add_argument("--input", "-i", help="path of GO file to be processed", required=True)
+#    parser.add_argument("--ontodir","-d",help="GO files directory (default ./onto)", 
+#                        default=os.getcwd()+"/onto")
     # parser.add_argument("--output","-o",help="Path of the output file",default="data/parseGO.parsed")
 
-    parser.add_argument("--keep_obsolete", "-k", help="Enter 1 if you want to keep the obsoletes", default=0)
+    # parser.add_argument("--keep_obsolete", "-k", help="Enter 1 if you want to keep obsolete terms", default=0)
     args = parser.parse_args()
     return args
 
@@ -123,8 +144,8 @@ def findAllCommonAncestorsAndDisjointCommonAncestors(mf_g, bp_g, cc_g, go1, go2)
     elif cc_g.has_node(go1):
         all_paths_go1 = nx.all_simple_paths(cc_g, source=go1, target=ROOT_CCO)
         cc += 1
-    """all_paths_go1=list(all_paths_go1)
-    all_paths_go1.append(go1)"""
+    # all_paths_go1=list(all_paths_go1)
+    # all_paths_go1.append(go1)
 
     if mf_g.has_node(go2):
         all_paths_go2 = nx.all_simple_paths(mf_g, source=go2, target=ROOT_MFO)
@@ -135,21 +156,11 @@ def findAllCommonAncestorsAndDisjointCommonAncestors(mf_g, bp_g, cc_g, go1, go2)
     elif cc_g.has_node(go2):
         all_paths_go2 = nx.all_simple_paths(cc_g, source=go2, target=ROOT_CCO)
         cc += 1
-    """all_paths_go2=list(all_paths_go2)
-    all_paths_go2.append(go2)"""
-
-    """print(list(all_paths_go1))
-    print(list(all_paths_go2))"""
 
     all_paths_go1 = list(all_paths_go1)
     all_paths_go2 = list(all_paths_go2)
 
-    """for path in all_paths_go1:
-        print(path)
-    print("*"*50)
-    for path in all_paths_go2:
-        print(path)"""
-    print((mf, bp, cc))
+    # print((mf, bp, cc))
     if mf == 2:
         current_graph = mf_g
         root_node = ROOT_MFO
@@ -185,34 +196,75 @@ def findAllCommonAncestorsAndDisjointCommonAncestors(mf_g, bp_g, cc_g, go1, go2)
     return common_ancestors, dca
 
 
-def findAllAncestorsForAllNodesForOntology(ontology):
-    graph = cp.load(open("data/" + ontology + ".graph", "rb"))
+def findAllAncestorsForAllNodesForOntology(ontology,ONTO_DIR):
+    # graph = cp.load(open("data/" + ontology + ".graph", "rb"))
+    print(ontology)
+    graph = cp.load(open(f"{ONTO_DIR}/{ontology}.graph", "rb"))
     graph_ancestors = dict()
     for nodes in graph.nodes():
         graph_ancestors[nodes] = findAllAncestors(graph, nodes)
     return graph_ancestors
 
+def init_globals(gothresh_ini_file="gothresher.ini"):
+    config = configparser.ConfigParser()
+    config.read(gothresh_ini_file)
+    print(config.sections())
+    global FILE_ALTERNATE_ID_TO_ID_MAPPING 
+    global FILE_CAFA_ID_TO_UNIPROT_ID_MAP 
+    global FILE_MFO_ONTOLOGY_GRAPH
+    global FILE_BPO_ONTOLOGY_GRAPH
+    global FILE_CCO_ONTOLOGY_GRAPH
+    global FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH
+    global FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH
+    global FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH
 
+    global ONTO_DIR
+    ONTO_DIR = os.path.abspath(config['DIRS']['ONTO_DIR'])
+    FILE_ALTERNATE_ID_TO_ID_MAPPING = "alt_to_id.graph"
+    FILE_CAFA_ID_TO_UNIPROT_ID_MAP = "CAFAIDTOUniprotIDMap.txt"
+    FILE_MFO_ONTOLOGY_GRAPH = "mf.graph"
+    FILE_BPO_ONTOLOGY_GRAPH = "bp.graph"
+    FILE_CCO_ONTOLOGY_GRAPH = "cc.graph"
+    FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = f"{ONTO_DIR}/mf_ancestors.map"
+    FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = f"{ONTO_DIR}/bp_ancestors.map"
+    FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = f"{ONTO_DIR}/cc_ancestors.map"
+
+    ROOT_BPO = config['GO']['root_bpo']
+    ROOT_CCO = config['GO']['root_cco']
+    ROOT_MFO = config['GO']['root_mfo']
+
+
+
+    
 def main():
     options = parseCommandLineArguments()
-    mf_g, bp_g, cc_g, alt_id_to_id_mapping = parseGOTerms(options.input, options.keep_obsolete)
-    """print(mf_g.has_node("GO:0019786"))
-    print(bp_g.has_node("GO:0019786"))
-    print(cc_g.has_node("GO:0019786"))"""
-    if os.path.isdir("data") == False:
-        os.makedirs("data")
-    cp.dump(mf_g, open(FILE_MFO_ONTOLOGY_GRAPH, "wb"))
-    cp.dump(bp_g, open(FILE_BPO_ONTOLOGY_GRAPH, "wb"))
-    cp.dump(cc_g, open(FILE_CCO_ONTOLOGY_GRAPH, "wb"))
-    cp.dump(alt_id_to_id_mapping, open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "wb"))
+    init_globals(options.config)
+    mf_g, bp_g, cc_g, alt_id_to_id_mapping = parseGOTerms(options.input)
+    #print(mf_g.has_node("GO:0019786"))
+    #print(bp_g.has_node("GO:0019786"))
+    #print(cc_g.has_node("GO:0019786"))
+    # if os.path.isdir("data") == False:
+    #    os.makedirs("data")
+    # Iddofix
+    if os.path.exists(ONTO_DIR):
+        if not os.path.isdir(ONTO_DIR):
+            raise ValueError(f"{ONTO_DIR} is not a directory")
+    else:
+        sys.stderr.write(f"{ONTO_DIR} does not exist. Creating...\n")
+        os.makedirs(ONTO_DIR)
+    # Iddo: fixed all paths to ONTO_DIR root path
+    cp.dump(mf_g, open(f"{ONTO_DIR}/{FILE_MFO_ONTOLOGY_GRAPH}", "wb"))
+    cp.dump(bp_g, open(f"{ONTO_DIR}/{FILE_BPO_ONTOLOGY_GRAPH}", "wb"))
+    cp.dump(cc_g, open(f"{ONTO_DIR}/{FILE_CCO_ONTOLOGY_GRAPH}", "wb"))
+    cp.dump(alt_id_to_id_mapping, open(f"{ONTO_DIR}/{FILE_ALTERNATE_ID_TO_ID_MAPPING}", "wb"))
 
-    mf_g = cp.load(open(FILE_MFO_ONTOLOGY_GRAPH, "rb"))
-    bp_g = cp.load(open(FILE_BPO_ONTOLOGY_GRAPH, "rb"))
-    cc_g = cp.load(open(FILE_CCO_ONTOLOGY_GRAPH, "rb"))
+    mf_g = cp.load(open(f"{ONTO_DIR}/{FILE_MFO_ONTOLOGY_GRAPH}", "rb"))
+    bp_g = cp.load(open(f"{ONTO_DIR}/{FILE_BPO_ONTOLOGY_GRAPH}", "rb"))
+    cc_g = cp.load(open(f"{ONTO_DIR}/{FILE_CCO_ONTOLOGY_GRAPH}", "rb"))
 
-    mf_ancestors = findAllAncestorsForAllNodesForOntology("mf")
-    bp_ancestors = findAllAncestorsForAllNodesForOntology("bp")
-    cc_ancestors = findAllAncestorsForAllNodesForOntology("cc")
+    mf_ancestors = findAllAncestorsForAllNodesForOntology("mf",ONTO_DIR)
+    bp_ancestors = findAllAncestorsForAllNodesForOntology("bp",ONTO_DIR)
+    cc_ancestors = findAllAncestorsForAllNodesForOntology("cc",ONTO_DIR)
 
     cp.dump(mf_ancestors, open(FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH, "wb"))
     cp.dump(bp_ancestors, open(FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH, "wb"))
